/*
 * MIT License
 *
 * Copyright (c) 2018 Choko (choko@curioswitch.org)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
import '@babel/polyfill';
import { createBrowserHistory } from 'history';
import React from 'react';
import ReactDOM from 'react-dom';
import { Provider } from 'react-redux';
import { ConnectedRouter } from 'react-router-redux';
import { ThemeProvider } from 'styled-components';
import LanguageProvider from '../containers/LanguageProvider';
import initI18n from '../i18n/init';
import initRedux from '../redux/init';
function render(messages, store, history, mountNode, Component, theme) {
    ReactDOM.render(<Provider store={store}>
      <LanguageProvider messages={messages}>
        <ThemeProvider theme={theme || {}}>
          <ConnectedRouter history={history}>
            <Component />
          </ConnectedRouter>
        </ThemeProvider>
      </LanguageProvider>
    </Provider>, mountNode);
}
export default function init(config) {
    const history = createBrowserHistory();
    const store = initRedux(config.initialState, history);
    const mountNode = config.mountNode
        ? typeof config.mountNode === 'string'
            ? document.getElementById(config.mountNode)
            : config.mountNode
        : document.getElementById('app');
    const formattedMessages = initI18n(config.defaultLocale, config.messages);
    const doRender = (component) => render(formattedMessages, store, history, mountNode, component, config.theme || {});
    if (!window.Intl) {
        import('intl')
            .then(() => import('intl/locale-data/jsonp/en.js'))
            .then(() => doRender(config.component))
            .catch((err) => {
            throw err;
        });
    }
    else {
        doRender(config.component);
    }
    return (component) => {
        ReactDOM.unmountComponentAtNode(mountNode);
        doRender(component);
    };
}
//# sourceMappingURL=init.jsx.map